define((function () { 'use strict';

	console.log('dep2');

	console.log('dep-b');

}));
